@@ -362,11 +362,13 @@ dir_copy:
                 }
 
                 if(!no_mkdir) {
+                    int result = mkdir(dfile, 0777);
+/*
                     mode_t umask_before = umask(0);
                     int result = mkdir(dfile, stat_.st_mode & (S_IRUSR|S_IWUSR|S_IXUSR
                             |S_IRGRP|S_IWGRP|S_IXGRP|S_IROTH|S_IWOTH|S_IXOTH));
                     umask(umask_before);
-
+*/
                     if(result <0)
                     {
                         closedir(dir);
@@ -398,6 +400,12 @@ dir_copy:
                     }
                 }
 
+                if(!no_mkdir) {
+                    mode_t umask_before = umask(0);
+                    chmod(dfile, stat_.st_mode & (S_IRUSR|S_IWUSR|S_IXUSR |S_IRGRP|S_IWGRP|S_IXGRP|S_IROTH|S_IWOTH|S_IXOTH));
+                    umask(umask_before);
+                }
+
                 if(preserve || move) {
                     if(getuid() == 0) {
                         if(chown(dfile, stat_.st_uid, stat_.st_gid) <0) {
