@@ -232,7 +232,7 @@ static void atexit_fun()
 ///////////////////////////////////////////////////
 static void sig_winch(int s)
 {
-    if(gMainLoop != -1) {
+    if(gMainLoop == -1) {
         mclear_immediately();       // 画面の再描写
         view(TRUE);
         mrefresh();
@@ -241,7 +241,7 @@ static void sig_winch(int s)
 
 static void sig_cont(int s)
 {
-    if(gMainLoop != -1) {
+    if(gMainLoop == -1) {
         mclear_immediately();       // 画面の再描写
         view(TRUE);
         mrefresh();
@@ -270,96 +270,6 @@ void set_signal_mfiler()
         perror("sigaction5");
         exit(1);
     }
-
-
-/*
-    struct sigaction sa;
-
-    memset(&sa, 0, sizeof(sa));
-    sa.sa_handler = SIG_IGN;
-    if(sigaction(SIGCHLD, &sa, NULL) < 0) {
-        perror("sigaction1");
-        exit(1);
-    }
-
-    struct sigaction sa2;
-
-    memset(&sa2, 0, sizeof(sa2));
-    sa2.sa_handler = sig_int;
-    if(sigaction(SIGINT, &sa2, NULL) < 0) {
-        perror("sigaction2");
-        exit(1);
-    }
-
-    struct sigaction sa4;
-
-    memset(&sa4, 0, sizeof(sa4));
-    sa4.sa_handler = SIG_IGN;
-    if(sigaction(SIGCONT, &sa4, NULL) < 0) {
-        perror("sigaction4");
-        exit(1);
-    }
-
-    struct sigaction sa5;
-
-    memset(&sa5, 0, sizeof(sa5));
-    sa5.sa_handler = sig_winch;
-    if(sigaction(SIGWINCH, &sa5, NULL) < 0) {
-        perror("sigaction5");
-        exit(1);
-    }
-
-    struct sigaction sa8;
-
-    memset(&sa8, 0, sizeof(sa8));
-    sa8.sa_handler = SIG_IGN;
-    if(sigaction(SIGPROF, &sa8, NULL) < 0) {
-        perror("sigaction8");
-        exit(1);
-    }
-
-    struct sigaction sa10;
-
-    memset(&sa10, 0, sizeof(sa10));
-    sa10.sa_handler = SIG_IGN;
-    if(sigaction(SIGTTOU, &sa10, NULL) < 0) {
-        perror("sigaction10");
-        exit(1);
-    }
-
-    struct sigaction sa11;
-
-    memset(&sa11, 0, sizeof(sa11));
-    sa11.sa_handler = SIG_IGN;
-    if(sigaction(SIGTTIN, &sa11, NULL) < 0) {
-        perror("sigaction11");
-        exit(1);
-    }
-
-    struct sigaction sa12;
-    memset(&sa12, 0, sizeof(sa12));
-    sa12.sa_handler = SIG_IGN;
-    if(sigaction(SIGTSTP, &sa12, NULL) < 0) {
-        perror("sigaction12");
-        exit(1);
-    }
-
-    struct sigaction sa13;
-    memset(&sa13, 0, sizeof(sa13));
-    sa13.sa_handler = SIG_IGN;
-    if(sigaction(SIGQUIT, &sa13, NULL) < 0) {
-        perror("sigaction13");
-        exit(1);
-    }
-    struct sigaction sa14;
-
-    memset(&sa4, 0, sizeof(sa14));
-    sa14.sa_handler = sig_cont;
-    if(sigaction(SIGCONT, &sa14, NULL) < 0) {
-        perror("sigaction2 on mfiler");
-        exit(1);
-    }
-*/
 }
 
 ///////////////////////////////////////////////////
@@ -830,7 +740,7 @@ int main(int argc, char* argv[])
 #endif
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.4.1", 1);
+    setenv("VERSION", "4.4.2", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
